using NT.AltText.Models;

namespace NT.AltText.Repository.Interfaces
{
    public interface IUserJobRepository
    {
        Task<IEnumerable<UserJobDetails>> GetAllJobsAsync();
        Task<UserJobDetails?> GetJobByIdAsync(int id);
        Task<int> AddAssignedJobAsync(UserJobDetails job);
        Task<UserJobDetails?> UpdateJobAsync(int id, UserJobDetails job);
        Task<bool> DeleteJobAsync(int id);
        Task<int> UpdateStatusByJobIdAndAssignedTo(UpdateStatusForJob updateStatusForJob);

    }
}
